@@ -1,6 +1,7 @@
 from odoo_somconnexio_python_client.client import Client
 from odoo_somconnexio_python_client.resources.address import Address
 
+from .sponsees import Sponsees
 from ..exceptions import ResourceNotFound
 
 
@@ -104,6 +105,21 @@ class Partner:
             raise ResourceNotFound(resource=cls.__name__, filter=params)
         return response_data["result"] == "allowed", response_data["message"]
 
+    @classmethod
+    def sponsees(cls, ref):
+        """
+        Get sponsees info from a Partner using the ref param.
+
+        :return: sponsees object if exists
+        """
+        url = Sponsees._url_path
+        params = {"ref": ref}
+        response_data = Client().get(url, params=params)
+        if not response_data:
+            raise ResourceNotFound(resource=cls.__name__, filter={})
+
+        return Sponsees(**response_data)
+
     @classmethod
     def _get(cls, id=None, params={}):
         if id:
