@@ -4,7 +4,7 @@ from odoo_somconnexio_python_client.client import Client
 class Provider:
     _url_path = "/provider"
 
-    def __init__(self, id, name):
+    def __init__(self, id, name, **kwargs):
         self.id = id
         self.name = name
 
